@@ -20,14 +20,18 @@ class RequestHandler:
         Execute request and return the JSON response
     """
 
-    def __init__(self, key):
+    def __init__(self, key, use_gzip):
         """
         :param str: The API key
+        :param bool: True if gzip compression should be used, False otherwise
         """
         # Initialize the session
         self.session = requests.Session()
         # Automatically add key header to all requests made within the session
         self.session.headers.update({'X-API-Key': key})
+        # Set header to allow gzip encoding to improve speed, if wanted
+        if use_gzip:
+            self.session.headers.update({'Accept-Encoding': 'gzip'})
 
     def execute_request(self, url, **params):
         """
